<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

// Add About section
$wp_customize->add_section( 'korpo_about_section', array(
	'title'             => esc_html__( 'About Us','korpo' ),
	'description'       => esc_html__( 'About Section options.', 'korpo' ),
	'panel'             => 'korpo_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'korpo_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'korpo_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Switch_Control( $wp_customize, 'korpo_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'korpo' ),
	'section'           => 'korpo_about_section',
	'on_off_label' 		=> korpo_switch_options(),
) ) );

// About us title setting and control
$wp_customize->add_setting( 'korpo_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'korpo' ),
	'section'        	=> 'korpo_about_section',
	'active_callback' 	=> 'korpo_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[about_sub_title]', array(
		'selector'            => '#about-us .about-section-wrapper span.section-subtitle',
		'settings'            => 'korpo_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_about_sub_title_partial',
    ) );
}

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'korpo_theme_options[about_content_page]', array(
	'sanitize_callback' => 'korpo_sanitize_page',
) );

$wp_customize->add_control( new Korpo_Dropdown_Chooser( $wp_customize, 'korpo_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'korpo' ),
	'section'           => 'korpo_about_section',
	'choices'			=> korpo_page_choices(),
	'active_callback'	=> 'korpo_is_about_section_enable',
) ) );

// About button setting and control
$wp_customize->add_setting( 'korpo_theme_options[about_btn_label]', array(
	'default'           => $options['about_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[about_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'korpo' ),
	'section'        	=> 'korpo_about_section',
	'active_callback' 	=> 'korpo_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[about_btn_label]', array(
		'selector'            => '#about-us .about-section-wrapper .entry-container .more-link a',
		'settings'            => 'korpo_theme_options[about_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_about_btn_label_partial',
    ) );
}