<?php
/**
 * Project Section options
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

// Add Project section
$wp_customize->add_section( 'korpo_project_section', array(
	'title'             => esc_html__( 'Projects','korpo' ),
	'description'       => esc_html__( 'Project Section options.', 'korpo' ),
	'panel'             => 'korpo_front_page_panel',
) );

// Project content enable control and setting
$wp_customize->add_setting( 'korpo_theme_options[project_section_enable]', array(
	'default'			=> 	$options['project_section_enable'],
	'sanitize_callback' => 'korpo_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Switch_Control( $wp_customize, 'korpo_theme_options[project_section_enable]', array(
	'label'             => esc_html__( 'Project Section Enable', 'korpo' ),
	'section'           => 'korpo_project_section',
	'on_off_label' 		=> korpo_switch_options(),
) ) );

// Project title setting and control
$wp_customize->add_setting( 'korpo_theme_options[project_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['project_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[project_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo' ),
	'section'        	=> 'korpo_project_section',
	'active_callback' 	=> 'korpo_is_project_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[project_title]', array(
		'selector'            => '#our-projects .projects-section-wrapper .entry-container .section-header span.section-subtitle',
		'settings'            => 'korpo_theme_options[project_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_project_title_partial',
    ) );
}

// project Section background setting and control.
$wp_customize->add_setting( 'korpo_theme_options[project_image]', array(
	'default'           => $options['project_image'],
	'sanitize_callback' => 'korpo_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'korpo_theme_options[project_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'korpo' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'korpo' ), 800, 800 ),
		'section'     		=> 'korpo_project_section',
		'active_callback'	=> 'korpo_is_project_section_enable',
) ) );

for ( $i = 1; $i <= 4; $i++ ) :

	// project pages drop down chooser control and setting
	$wp_customize->add_setting( 'korpo_theme_options[project_content_page_' . $i . ']', array(
		'sanitize_callback' => 'korpo_sanitize_page',
	) );

	$wp_customize->add_control( new Korpo_Dropdown_Chooser( $wp_customize, 'korpo_theme_options[project_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'korpo' ), $i ),
		'section'           => 'korpo_project_section',
		'choices'			=> korpo_page_choices(),
		'active_callback'	=> 'korpo_is_project_section_enable',
	) ) );

endfor;
