<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

$options = korpo_get_theme_options();


if ( ! function_exists( 'korpo_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Korpo 1.0.0
	 */
	function korpo_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'korpo_doctype', 'korpo_doctype', 10 );


if ( ! function_exists( 'korpo_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'korpo_before_wp_head', 'korpo_head', 10 );

if ( ! function_exists( 'korpo_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'korpo' ); ?></a>

		<?php
	}
endif;

add_action( 'korpo_page_start_action', 'korpo_page_start', 10 );


if ( ! function_exists( 'korpo_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'korpo_page_end_action', 'korpo_page_end', 10 );

if ( ! function_exists( 'korpo_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_header_start() { ?>
		<div class="menu-overlay"></div>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
		<?php
	}
endif;
add_action( 'korpo_header_action', 'korpo_header_start', 10 );

if ( ! function_exists( 'korpo_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_site_branding() {
		$options  = korpo_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
			<?php 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) {
				the_custom_logo();
			} 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( korpo_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'korpo_header_action', 'korpo_site_branding', 20 );

if ( ! function_exists( 'korpo_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_site_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
				echo korpo_get_svg( array( 'icon' => 'menu' ) );
				echo korpo_get_svg( array( 'icon' => 'close' ) );
				?>					
			</button>

			<?php  
				$search = '<li class="search-menu"><a href="#" class="search">';
				$search .= korpo_get_svg( array( 'icon' => 'search' ) );
				$search .= korpo_get_svg( array( 'icon' => 'close' ) );
				$search .= '</a><div id="search">';
				$search .= get_search_form( $echo = false );
                $search .= '</div><!-- #search --></li>';

        		$defaults = array(
        			'theme_location' => 'primary',
        			'container' => false,
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'korpo_menu_fallback_cb',
        			'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s' . $search . '</ul>',
        		);
        	
        		wp_nav_menu( $defaults );
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'korpo_header_action', 'korpo_site_navigation', 30 );


if ( ! function_exists( 'korpo_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'korpo_header_action', 'korpo_header_end', 50 );

if ( ! function_exists( 'korpo_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'korpo_content_start_action', 'korpo_content_start', 10 );

if ( ! function_exists( 'korpo_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Architectonic Pro 1.0.0
	 */
	function korpo_add_breadcrumb() {
		$options = korpo_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( korpo_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * korpo_simple_breadcrumb hook
				 *
				 * @hooked korpo_simple_breadcrumb -  10
				 *
				 */
				do_action( 'korpo_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;
add_action( 'korpo_breadcrumb_action', 'korpo_add_breadcrumb', 10 );

if ( ! function_exists( 'korpo_custom_header' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_custom_header() {
		if ( korpo_is_frontpage() ) {
			return;
		}
		$options = korpo_get_theme_options();
		$header_image = get_header_image();
		$header_image = ! empty( $header_image ) ? $header_image : get_template_directory_uri() . '/assets/uploads/custom-header-image.jpg';
		?>
		<div id="banner-image" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="page-site-header">
                <div class="wrapper">
                	<?php if ( is_single() ) : ?>
	                    <div class="entry-meta">
	                        <?php 
                         	if ( ! $options['single_post_hide_category'] ) :
                            	echo korpo_categories(); 
                        	endif;

                            if ( ! $options['single_post_hide_date'] ) :
                            	korpo_posted_on(); 
                            endif;
                            ?>
	                    </div><!-- .entry-meta -->
	                <?php endif; ?>

                    <header class="page-header">
                        <h2 class="page-title"><?php echo korpo_custom_header_banner_title(); ?></h2>
                    </header><!-- .page-header -->

                    <?php  
                    /**
					 * korpo_breadcrumb_action hook
					 *
					 * @hooked korpo_add_breadcrumb -  10
					 *
					 */
					do_action( 'korpo_breadcrumb_action' );
                    ?>
                </div><!-- .wrapper -->
            </div><!-- #page-site-header -->
        </div><!-- #banner-image -->

	<?php
	}
endif;
add_action( 'korpo_content_start_action', 'korpo_custom_header', 20 );

if ( ! function_exists( 'korpo_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'korpo_content_end_action', 'korpo_content_end', 10 );

if ( ! function_exists( 'korpo_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'korpo_footer', 'korpo_footer_start', 10 );

if ( ! function_exists( 'korpo_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_footer_site_info() {
		$theme_data = wp_get_theme();
		$options = korpo_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

		$powered_by_text = esc_html__( 'All Rights Reserved | ', 'korpo' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'korpo' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>';
        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
        $powered_by_text = str_replace( $search, $replace, $powered_by_text );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info col-2">
            <div class="wrapper">
                <span>
                	<?php 
                	echo korpo_santize_allow_tag( $copyright_text ); 
                	if ( function_exists( 'the_privacy_policy_link' ) ) {
					    the_privacy_policy_link( '<span class="sep"> | </span>' );
					}
                	?>
                </span><!-- .copyright -->
                    	
                <span>
                    <?php echo korpo_santize_allow_tag( $powered_by_text ); ?>
                </span><!-- .powered-by -->
            </div><!-- .wrapper -->    
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'korpo_footer', 'korpo_footer_site_info', 40 );

if ( ! function_exists( 'korpo_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_footer_scroll_to_top() {
		$options  = korpo_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo korpo_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'korpo_footer', 'korpo_footer_scroll_to_top', 40 );

if ( ! function_exists( 'korpo_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Korpo 1.0.0
	 *
	 */
	function korpo_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'korpo_footer', 'korpo_footer_end', 100 );

